@@ -20,7 +20,33 @@
 #ifndef __CALF_GUI_CONTROLS_H
 #define __CALF_GUI_CONTROLS_H
 
-#include "gui.h"
+#include <config.h>
+#include <assert.h>
+#include <sys/time.h>
+#include <calf/ctl_curve.h>
+#include <calf/ctl_keyboard.h>
+#include <calf/ctl_knob.h>
+#include <calf/ctl_led.h>
+#include <calf/ctl_tube.h>
+#include <calf/ctl_vumeter.h>
+#include <calf/ctl_frame.h>
+#include <calf/ctl_fader.h>
+#include <calf/ctl_notebook.h>
+#include <calf/ctl_meterscale.h>
+#include <calf/ctl_phasegraph.h>
+#include <calf/ctl_linegraph.h>
+#include <calf/ctl_buttons.h>
+#include <calf/ctl_tuner.h>
+#include <calf/ctl_combobox.h>
+#include <calf/ctl_pattern.h>
+#include <calf/giface.h>
+#include <calf/gui.h>
+#include <calf/utils.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkkeysyms.h>
+#include <iostream>
+#include <vector>
+#include <algorithm>
 
 struct CalfCurve;
 struct CalfKeyboard;
@@ -178,11 +204,12 @@ struct toggle_param_control: public param_control
 struct tap_button_param_control: public param_control
 {
     guint last_time;
-    unsigned long init_time;
+    gint timer;
     float avg_value, value;
     virtual GtkWidget *create(plugin_gui *_gui, int _param_no);
     virtual void get();
     virtual void set();
+    static void tap_button_stop_waiting(gpointer value);
     static gboolean tap_button_released(GtkWidget *widget, gpointer value);
     static gboolean tap_button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer value);
 };
@@ -247,6 +274,28 @@ struct phase_graph_param_control: public param_control
     virtual ~phase_graph_param_control();
 };
 
+/// Tuner
+struct tuner_param_control: public param_control
+{
+    virtual GtkWidget *create(plugin_gui *_gui, int _param_no);
+    virtual void get() {}
+    virtual void set();
+    virtual void on_idle();
+    int cents_no;
+    virtual ~tuner_param_control();
+};
+
+/// Pattern
+struct pattern_param_control: public param_control
+{
+    virtual GtkWidget *create(plugin_gui *_gui, int _param_no);
+    virtual void get() {}
+    virtual void set();
+    virtual void send_configure(const char *key, const char *value);
+    static void on_handle_changed(CalfPattern *widget, calf_pattern_handle *handle, pattern_param_control *pThis);
+    int param_bars, param_beats;
+};
+
 /// Knob
 struct knob_param_control: public param_control
 {
@@ -264,6 +313,7 @@ struct keyboard_param_control: public param_control
     virtual GtkWidget *create(plugin_gui *_gui, int _param_no);
     virtual void get() {}
     virtual void set() {}
+    virtual void send_configure(const char *key, const char *value) {}
 };
 
 /// Curve editor
@@ -277,6 +327,15 @@ struct curve_param_control: public param_control, public send_configure_iface
     virtual void send_configure(const char *key, const char *value);
 };
 
+/// Meter scale
+struct meter_scale_param_control: public param_control, public send_configure_iface
+{
+    virtual GtkWidget *create(plugin_gui *_gui, int _param_no);
+    virtual void get() {}
+    virtual void set() {}
+    virtual void send_configure(const char *key, const char *value) {};
+};
+
 /// Text entry
 struct entry_param_control: public param_control, public send_configure_iface
 {
