@@ -30,6 +30,10 @@ using namespace calf_plugins;
 
 #define SET_IF_CONNECTED(name) if (params[AM::param_##name] != NULL) *params[AM::param_##name] = name;
 
+FORWARD_DECLARE_METADATA(limiter)
+FORWARD_DECLARE_METADATA(multibandlimiter)
+FORWARD_DECLARE_METADATA(sidechainlimiter)
+
 /**********************************************************************
  * LIMITER by Christian Holschuh and Markus Schmidt
 **********************************************************************/
@@ -112,6 +116,8 @@ uint32_t limiter_audio_module::process(uint32_t offset, uint32_t numsamples, uin
     } else {
         asc_led   -= std::min(asc_led, numsamples);
 
+        // allocate fickdich on the stack before entering loop
+        STACKALLOC(float, fickdich, limiter.overall_buffer_size);
         while(offset < numsamples) {
             // cycle through samples
             float inL = ins[0][offset];
@@ -131,7 +137,6 @@ uint32_t limiter_audio_module::process(uint32_t offset, uint32_t numsamples, uin
             float tmpR;
             
             // process gain reduction
-            STACKALLOC(float, fickdich, limiter.overall_buffer_size);
             for (int i = 0; i < *params[param_oversampling]; i ++) {
                 tmpL = samplesL[i];
                 tmpR = samplesR[i];
@@ -147,7 +152,7 @@ uint32_t limiter_audio_module::process(uint32_t offset, uint32_t numsamples, uin
             outR = resampler[1].downsample(samplesR);
             
             // should never be used. but hackers are paranoid by default.
-            // so we make shure NOTHING is above limit
+            // so we make sure NOTHING is above limit
             outL = std::min(std::max(outL, -*params[param_limit]), *params[param_limit]);
             outR = std::min(std::max(outR, -*params[param_limit]), *params[param_limit]);
 
@@ -352,6 +357,8 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
     } else {
         // process all strips
         asc_led     -= std::min(asc_led, numsamples);
+        // allocate fickdich on the stack before entering loop to avoid buffer overflow
+        STACKALLOC(float, fickdich, broadband.overall_buffer_size);
         while(offset < numsamples) {
             float inL  = 0.f; // input
             float inR  = 0.f;
@@ -461,7 +468,6 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
                 }
                 
                 // process broadband limiter
-                STACKALLOC(float, fickdich, broadband.overall_buffer_size);
                 tmpL = resL[o];
                 tmpR = resR[o];
                 broadband.process(tmpL, tmpR, fickdich);
@@ -477,7 +483,7 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
             //if(!(cnt%50)) printf("o: %.5f %.5f\n\n", outL, resL[0]);
             
             // should never be used. but hackers are paranoid by default.
-            // so we make shure NOTHING is above limit
+            // so we make sure NOTHING is above limit
             outL = std::min(std::max(outL, -*params[param_limit]), *params[param_limit]);
             outR = std::min(std::max(outR, -*params[param_limit]), *params[param_limit]);
             
@@ -546,7 +552,7 @@ uint32_t multibandlimiter_audio_module::process(uint32_t offset, uint32_t numsam
             //asc_active = asc_active || broadband.get_asc();
             
             //// should never be used. but hackers are paranoid by default.
-            //// so we make shure NOTHING is above limit
+            //// so we make sure NOTHING is above limit
             //outL = std::max(outL, -*params[param_limit]);
             //outL = std::min(outL, *params[param_limit]);
             //outR = std::max(outR, -*params[param_limit]);
@@ -750,6 +756,8 @@ uint32_t sidechainlimiter_audio_module::process(uint32_t offset, uint32_t numsam
     } else {
         // process all strips
         asc_led     -= std::min(asc_led, numsamples);
+        // allocate fickdich on the stack before loops to avoid buffer overflow
+        STACKALLOC(float, fickdich, broadband.overall_buffer_size);
         while(offset < numsamples) {
             float inL  = 0.f; // input
             float inR  = 0.f;
@@ -846,7 +854,6 @@ uint32_t sidechainlimiter_audio_module::process(uint32_t offset, uint32_t numsam
                 }
                 
                 // process broadband limiter
-                STACKALLOC(float, fickdich, broadband.overall_buffer_size);
                 tmpL = resL[o];
                 tmpR = resR[o];
                 broadband.process(tmpL, tmpR, fickdich);
@@ -862,7 +869,7 @@ uint32_t sidechainlimiter_audio_module::process(uint32_t offset, uint32_t numsam
             //if(!(cnt%50)) printf("o: %.5f %.5f\n\n", outL, resL[0]);
             
             // should never be used. but hackers are paranoid by default.
-            // so we make shure NOTHING is above limit
+            // so we make sure NOTHING is above limit
             outL = std::min(std::max(outL, -*params[param_limit]), *params[param_limit]);
             outR = std::min(std::max(outR, -*params[param_limit]), *params[param_limit]);
             
